@@ -1,9 +1,17 @@
-#![allow(non_snake_case)]
-pub mod Microsoft;
+#[allow(non_snake_case)]
+pub mod Microsoft {
+    #[allow(non_snake_case)]
+    pub mod Web {
+        #[allow(non_snake_case)]
+        pub mod WebView2 {
+            #[allow(non_snake_case)]
+            pub mod Win32;
+        }
+    }
+}
 
 pub(crate) use ::windows as Windows;
 
-pub mod browser_version;
 pub mod callback_interfaces;
 
 #[cfg(test)]
